@@ -188,7 +188,7 @@ def mean(input, dim):
 
 
 def reduce_mean(input):
-    return tf.reduce_mean(input)
+    return th.reduce_mean(input)
 
 
 def max(input, dim):
@@ -409,10 +409,6 @@ def clamp(data, min_val, max_val):
 def replace_inf_with_zero(x):
     return tf.where(tf.abs(x) == np.inf, 0, x)
 
-def count_nonzero(input):
-    return int(tf.math.count_nonzero(input))
-
-
 def unique(input):
     return tf.unique(input).y
 
